library(xts)
library(dplyr)
#Read a timeseries data file (e.g.- DC_ANZ_dividend.csv) and extract relevant columns.
dataframe=read.csv("DC_ANZ_dividend.csv",stringsAsFactors=FALSE)
dataframe = dataframe %>% select(Annualised.Dividend.Net.Amount, Dividend.Ex.Date) 
dataframe=na.omit(dataframe) #Remove NA values.
dataframe$Dividend.Ex.Date<-as.Date(dataframe$Dividend.Ex.Date,format="%m/%d/%Y") #Convert date column into standard format
dataframe<-arrange(dataframe,Dividend.Ex.Date) #Sort data by date column
#Add columns for event type and instrument ID and put columns in right order.
dataframe$Event_Type="Dividend"
dataframe$Instrument_ID="ANZ" 
dataframe_csv <- data.frame(dataframe$Dividend.Ex.Date,dataframe$Instrument_ID,dataframe$Event_Type,dataframe$Annualised.Dividend.Net.Amount)
dataframe_csv <- setNames(dataframe_csv,c("Timestamp","EventType","InstrumentID","Annualised.Dividend.Net.Amount"))
write.csv(dataframe_csv,"AD_ANZ_dividends.csv",row.names=FALSE)
#Create the date_list that will be used to index the rds object. Note that when converting you have the specify the format of the existing dates ("%m/%d/%Y") as the dates are not recorder in a standard format.
date_list= as.POSIXct(as.Date(dataframe$Dividend.Ex.Date,format = "%m/%d/%Y"))
date_list = round(date_list ,units='days')
head(date_list)
#[1] "2004-05-14 AEST" "2004-11-08 AEDT" "2005-05-16 AEST" "2005-11-08 AEDT" "2006-05-15 AEST"
#[6] "2006-11-09 AEDT"
#Remove date column from the data and create the xts object.
dataframe_rds <- data.frame(dataframe$Instrument_ID,dataframe$Event_Type,dataframe$Annualised.Dividend.Net.Amount)
dataframe_rds <- setNames(dataframe_rds,c("EventType","InstrumentID","Annualised.Dividend.Net.Amount"))
xts_object = xts(dataframe_rds,order.by = date_list)
#save it as an R object with time index. 
saveRDS(xts_object,file="AD_ANZ_dividends.rds")
